# MCP Server
### On this page
  * [Introduction to MCP](https://help.sap.com/docs/leanix/ea/mcp-server#introduction-to-mcp)
  * [How the MCP Server Works](https://help.sap.com/docs/leanix/ea/mcp-server#how-the-mcp-server-works)
  * [Benefits](https://help.sap.com/docs/leanix/ea/mcp-server#benefits)
  * [Connecting to the MCP Server](https://help.sap.com/docs/leanix/ea/mcp-server#connecting-to-the-mcp-server)
  * [Tools](https://help.sap.com/docs/leanix/ea/mcp-server#tools)
  * [Streaming Mechanism](https://help.sap.com/docs/leanix/ea/mcp-server#streaming-mechanism)
  * [Example Requests](https://help.sap.com/docs/leanix/ea/mcp-server#example-requests)


Connect external AI applications to SAP LeanIX using the Model Context Protocol (MCP) server to securely access enterprise architecture data.
